@@ -4,16 +4,15 @@ from pykechain.enums import Enum
 
 
 class FirstEnum(Enum):
-    SLUG_1 = 'first slug'
+    SLUG_1 = "first slug"
 
 
 class SecondEnum(FirstEnum):
-    SLUG_2 = 'second slug'
+    SLUG_2 = "second slug"
 
 
 class TestEnums(TestCase):
-
     def test_inheritance(self):
         values = SecondEnum.values()
 
-        self.assertIn('first slug', values)
+        self.assertIn("first slug", values)
